@@ -162,6 +162,13 @@ typedef struct {
 
     /** preferred dialog height */
     gint preferred_height;
+
+    /** color value for the tachometers, useful for dark themes where lower brightness is required */
+    gfloat val_tachos_color;
+
+    /** desired alpha value for the tachometers */
+    gfloat val_tachos_alpha;
+
 }
 t_sensors;
 
