@@ -127,6 +127,9 @@ sensors_init_default_values  (t_sensors *ptr_sensors, XfcePanelPlugin *ptr_xfcep
 
     ptr_sensors->show_smallspacings = FALSE;
 
+    ptr_sensors->val_tachos_color = MAX_HUE;
+    ptr_sensors->val_tachos_alpha = ALPHA_CHANNEL_VALUE;
+
     font = g_strdup("Sans 11");
 
     TRACE ("leaves sensors_init_default_values");
@@ -155,10 +158,18 @@ format_sensor_value (t_tempscale temperaturescale, t_chipfeature *ptr_chipfeatur
                *dptr_str_formattedvalue = g_strdup_printf(_("%+.3f V"), val_sensorfeature);
                break;
 
+        case CURRENT:
+               *dptr_str_formattedvalue = g_strdup_printf(_("%+.3f A"), val_sensorfeature);
+               break;
+
         case ENERGY:
                *dptr_str_formattedvalue = g_strdup_printf(_("%.0f mWh"), val_sensorfeature);
                break;
 
+        case POWER:
+               *dptr_str_formattedvalue = g_strdup_printf(_("%.3f W"), val_sensorfeature);
+               break;
+
         case STATE:
                 if (val_sensorfeature==0.0)
                     *dptr_str_formattedvalue = g_strdup (_("off"));
