@@ -986,16 +986,75 @@ sensors_show_text_display (t_sensors *ptr_sensors)
 
 
 /* -------------------------------------------------------------------------- */
-/* create tooltip
-Updates the sensor values, see lines 440 and following */
+/* Updates the sensor values */
 static gboolean
-sensors_create_tooltip (gpointer ptr_argument)
+sensors_update_values (gpointer ptr_argument)
 {
     t_sensors *ptr_sensors;
     int idx_sensorchips, index_feature, result;
     double val_sensorfeature;
+    gchar *ptr_str_tmp;
+    t_chipfeature *ptr_chipfeature;
+    t_chip *ptr_chipstructure;
+
+    TRACE ("enters sensors_update_values");
+
+
+    g_return_val_if_fail (ptr_argument != NULL, FALSE);
+
+    ptr_sensors = (t_sensors *) ptr_argument;
+
+    for (idx_sensorchips=0; idx_sensorchips < ptr_sensors->num_sensorchips; idx_sensorchips++) {
+        ptr_chipstructure = (t_chip *) g_ptr_array_index (ptr_sensors->chips, idx_sensorchips);
+        g_assert (ptr_chipstructure!=NULL);
+
+
+        for (index_feature = 0; index_feature<ptr_chipstructure->num_features; index_feature++) {
+            ptr_chipfeature = g_ptr_array_index (ptr_chipstructure->chip_features, index_feature);
+            g_assert (ptr_chipfeature!=NULL);
+
+            if ( ptr_chipfeature->valid == TRUE && ptr_chipfeature->show == TRUE ) {
+
+                result = sensor_get_value (ptr_chipstructure, ptr_chipfeature->address,
+                                                    &val_sensorfeature,
+                                                    &(ptr_sensors->suppressmessage));
+
+                if (result != 0) {
+                    /* output to stdout on command line, not very useful for user, except for tracing problems */
+                    g_printf ( _("Sensors Plugin:\n"
+                    "Seems like there was a problem reading a sensor feature "
+                    "value.\nProper proceeding cannot be guaranteed.\n") );
+                    break;
+                }
+                ptr_str_tmp = g_new (gchar, 0);
+                format_sensor_value (ptr_sensors->scale, ptr_chipfeature,
+                                     val_sensorfeature, &ptr_str_tmp);
+
+                if (ptr_chipfeature->formatted_value != NULL)
+                    g_free (ptr_chipfeature->formatted_value);
+
+                ptr_chipfeature->formatted_value = g_strdup (ptr_str_tmp);
+                ptr_chipfeature->raw_value = val_sensorfeature;
+
+                g_free (ptr_str_tmp);
+            } /* end if ptr_chipfeature->valid */
+        }
+    }
+
+    TRACE ("leaves sensors_update_values");
+
+    return TRUE;
+}
+
+/* -------------------------------------------------------------------------- */
+/* create tooltip,see lines 440 and following */
+static gboolean
+sensors_create_tooltip (gpointer ptr_argument)
+{
+    t_sensors *ptr_sensors;
+    int idx_sensorchips, index_feature;
     gboolean is_first_textline, is_chipname_already_prepended;
-    gchar *ptr_str_tooltip, *ptr_str_tooltiptext, *ptr_str_tmp;
+    gchar *ptr_str_tooltip, *ptr_str_tooltiptext;
     t_chipfeature *ptr_chipfeature;
     t_chip *ptr_chipstructure;
 
@@ -1037,34 +1096,11 @@ sensors_create_tooltip (gpointer ptr_argument)
                     is_chipname_already_prepended = TRUE;
                 }
 
-                result = sensor_get_value (ptr_chipstructure, ptr_chipfeature->address,
-                                                    &val_sensorfeature,
-                                                    &(ptr_sensors->suppressmessage));
-
-                if (result != 0) {
-                    /* output to stdout on command line, not very useful for user, except for tracing problems */
-                    g_printf ( _("Sensors Plugin:\n"
-                    "Seems like there was a problem reading a sensor feature "
-                    "value.\nProper proceeding cannot be guaranteed.\n") );
-                    break;
-                }
-                ptr_str_tmp = g_new (gchar, 0);
-                format_sensor_value (ptr_sensors->scale, ptr_chipfeature,
-                                     val_sensorfeature, &ptr_str_tmp);
-
                 ptr_str_tooltiptext = g_strconcat (ptr_str_tooltip, "\n  ",
-                                             ptr_chipfeature->name, ": ", ptr_str_tmp,
+                                             ptr_chipfeature->name, ": ", ptr_chipfeature->formatted_value,
                                              NULL);
                 g_free (ptr_str_tooltip);
                 ptr_str_tooltip = ptr_str_tooltiptext;
-
-                if (ptr_chipfeature->formatted_value != NULL)
-                    g_free (ptr_chipfeature->formatted_value);
-
-                ptr_chipfeature->formatted_value = g_strdup (ptr_str_tmp);
-                ptr_chipfeature->raw_value = val_sensorfeature;
-
-                g_free (ptr_str_tmp);
             } /* end if ptr_chipfeature->valid */
         }
     }
@@ -1093,6 +1129,8 @@ sensors_show_panel (gpointer ptr_argument)
 
     ptr_sensors = (t_sensors *) ptr_argument;
 
+    sensors_update_values(ptr_argument);
+
     switch (ptr_sensors->display_values_type)
     {
       case DISPLAY_TACHO:
@@ -2183,6 +2221,9 @@ add_cover_rows_box (GtkWidget * vbox, t_sensors_dialog * sd)
 
     if (xfce_panel_plugin_get_mode(sd->sensors->plugin) != XFCE_PANEL_PLUGIN_MODE_DESKBAR)
     {
+        // The Xfce 4 panel can have several rows or columns. With such a mode,
+        //  the plugins are allowed to span over all available rows/columns.
+        //  When translating, "cover" might be replaced by "use" or "span".
         myCheckBox = gtk_check_button_new_with_mnemonic (_("_Cover all panel rows/columns"));
         gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(myCheckBox), sd->sensors->cover_panel_rows);
 
@@ -2335,9 +2376,8 @@ add_tachos_appearance_boxes(GtkWidget * vbox, t_sensors_dialog * sd)
     //GtkWidget *widget_groupbox;
     TRACE ("enters add_tachos_appearance_boxes");
 
-//widget_groupbox = xfce_groub_box ...
-
     sd->alpha_slider_box = gtk_hbox_new(FALSE, INNER_BORDER);
+    // Alpha value of the tacho coloring
     widget_label = gtk_label_new(_("Tacho color alpha value:"));
     gtk_widget_show (widget_label);
     gtk_box_pack_start (GTK_BOX (sd->alpha_slider_box), widget_label, FALSE, TRUE, 0);
@@ -2466,7 +2506,7 @@ add_command_box (GtkWidget * vbox,  t_sensors_dialog * sd)
 static void
 add_view_frame (GtkWidget * notebook, t_sensors_dialog * sd)
 {
-    GtkWidget *_vbox, *_label;
+    GtkWidget *_vbox, *_label, *_frame;
 
     TRACE ("enters add_view_frame");
 
@@ -2486,6 +2526,17 @@ add_view_frame (GtkWidget * notebook, t_sensors_dialog * sd)
     add_ui_style_box (_vbox, sd);
     add_labels_box (_vbox, sd);
     add_cover_rows_box(_vbox, sd);
+
+    _frame = gtk_frame_new(_("UI style options"));
+    gtk_frame_set_shadow_type(GTK_FRAME(_frame), GTK_SHADOW_ETCHED_IN);
+    gtk_box_pack_start (GTK_BOX (_vbox), _frame, FALSE, FALSE, 0);
+    gtk_widget_show (_frame);
+
+    _vbox = gtk_vbox_new (FALSE, OUTER_BORDER);
+    gtk_container_set_border_width(GTK_CONTAINER(_vbox), OUTER_BORDER);
+    gtk_container_add(GTK_CONTAINER(_frame), _vbox);
+    gtk_widget_show (_vbox);
+
     add_str_fontsize_box (_vbox, sd);
     add_font_settings_box (_vbox, sd);
     add_lines_box (_vbox, sd);
